#
# spec file for package amanda
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?suse_version} <= 1110
    %define amanda_group disk
%else
    %define amanda_group amanda
%endif

Name:           amanda
BuildRequires:  dump glib2-devel gnuplot krb5-devel perl-base popt-devel samba-client sendmail
BuildRequires:  cups-libs gawk libsmbclient libsmbclient-devel libxslt mailx mtx openssh readline-devel
%define package_version 2.6.1p1  
Version:        2.6.1.1
Release:        16.1
PreReq:         pwdutils permissions
Requires:       dump /usr/bin/smbclient
Requires:       perl = %{perl_version}
AutoReqProv:    on
Group:          Productivity/Archiving/Backup
License:        GPLv2+ ; MIT License (or similar)
Url:            http://www.amanda.org/
Summary:        Network Disk Archiver
Source:         %{name}-%{package_version}.tar.bz2
#amanda-SuSE.tar.bz2 contain init scripts, config examples
Source1:        %{name}-SuSE.tar.bz2
Source2:        amanda-howto-collection.pdf.tar.bz2
Patch1:         %{name}-%{package_version}-pie.patch
Patch3:         %{name}-%{package_version}-shellbang.patch
Patch4:         %{name}-%{package_version}-return_val.patch
Patch5:         %{name}-%{package_version}-newer_glib.patch
Patch6:         %{name}-permission.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This is a release of Amanda, the Advanced Maryland Automatic Network
Disk Archiver.	Amanda is a backup system designed to archive many
computers on a network to a single large-capacity tape drive.



Authors:
--------
    James da Silva <jds@cs.umd.edu>
    Mike Grupenhoff <kashmir@munge.com>
    Todd Kover <kovert@uu.net>
    James Mathiesen <James-Mathiesen@deshaw.com>
    Alan McIvor <a.mcivor@irl.cri.nz>
    George Scott <George.Scott@cc.monash.edu.au>
    Alexandre Oliva <oliva@dcc.unicamp.br>
    Blair Zajac <blair@gps.caltech.edu>
    Curtis Varner <cvarner@cs.ucr.edu>
    John R. Jackson <jrj@gandalf.cc.purdue.edu>
    Jean-Louis Martineau <martinea@iro.umontreal.edu>

%prep
%setup -q -a 1 -a 2 -n %{name}-%{package_version}
%patch1 -p1
%patch3
%patch4
%patch5
%patch6 -p1

%build
./autogen
CFLAGS="$RPM_OPT_FLAGS -U BUILD_DATE -U BUILD_MACH -fno-strict-aliasing -fPIC" CXXFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing -fPIC" \
	./configure --mandir=%{_mandir} \
          --with-bsdtcp-security \
          --with-bsdudp-security \
          --prefix=%{_prefix} \
          --infodir=%{_infodir} \
          --sysconfdir=%{_sysconfdir} \
          --libdir=%{_libdir} \
          --libexecdir=/usr/lib \
          --localstatedir=/var/lib \
          --with-index-server=localhost \
          --with-gnutar-listdir=/var/lib/amanda/gnutar-lists \
          --with-smbclient=%{_prefix}/bin/smbclient \
          --with-amperldir=%{perl_vendorlib} \
          --with-user=amanda \
          --with-group=%{amanda_group} \
          --with-gnutar=/bin/tar \
          --disable-libtool \
          --with-amandahosts \
          --disable-installperms
make

%install
make DESTDIR=$RPM_BUILD_ROOT/ install
install -d $RPM_BUILD_ROOT/%{_sysconfdir}/amanda \
           $RPM_BUILD_ROOT/var/lib/amanda/index \
           $RPM_BUILD_ROOT/var/lib/amanda/gnutar-lists \
           $RPM_BUILD_ROOT/var/lib/amanda/disklist \
           $RPM_BUILD_ROOT/var/lib/amanda/DailySet1 \
           $RPM_BUILD_ROOT/var/lib/amanda/lbl-templ \
           $RPM_BUILD_ROOT/%{_docdir}/%{name} \
           $RPM_BUILD_ROOT/%{_sysconfdir}/xinetd.d
install NEWS README README.SuSE example/{amanda.conf,chg-multi.conf,disklist} $RPM_BUILD_ROOT/%{_docdir}/%{name}
chmod 644 $RPM_BUILD_ROOT/%{_docdir}/%{name}/* \
          $RPM_BUILD_ROOT/%{_mandir}/*/*
cp -a SuSE/* $RPM_BUILD_ROOT
#we must change group name for amanada user in xinit'd scripts for 11.1 and lower
%if 0%{?suse_version} <= 1110
    %__sed -i 's|amanda|disk|' $RPM_BUILD_ROOT/etc/xinetd.d/am*
%endif
# pdf doc
cp amanda-howto-collection.pdf $RPM_BUILD_ROOT/%{_docdir}/%{name}/
# label templates
cp -a example/*.ps $RPM_BUILD_ROOT/var/lib/amanda/lbl-templ
# contain docs,examples which are already included
rm -rf $RPM_BUILD_ROOT/usr/share/amanda
# bnc#412636
touch $RPM_BUILD_ROOT//usr/lib/amanda/exclude.gtar
# create a list of binaries to be checked externally
cat << EOF > $RPM_BUILD_ROOT/usr/lib/amanda/suidlist
/usr/sbin/amcheck
/usr/lib/amanda/calcsize
/usr/lib/amanda/rundump
/usr/lib/amanda/planner
/usr/lib/amanda/runtar
/usr/lib/amanda/dumper
/usr/lib/amanda/killpgrp
EOF

%pre
# since 11.2 we use group "tape" instead of "disk" for tape devices /dev/nst*, so we must check group for "amanda" user
%if 0%{?suse_version} > 1110
#create primary group for amanda user
    /usr/sbin/groupadd -r amanda 2>/dev/null || :
#if user already exists and has effective group "disk" we have to change this group to "amanda" group and also add supplementary "tape" group see bnc#523006
    /usr/bin/id -n -g amanda 2>&1 | grep "disk" >/dev/null && /usr/sbin/usermod -g amanda -G tape amanda  /usr/sbin/usermod -g amanda amanda 2>&1
#this is ugly but just simple add user with "tape" and "amanda" groups regardless of existing user
    /usr/sbin/useradd -r -o -g amanda -G tape -u 37 -s /bin/bash -c "Amanda admin" -d /var/lib/amanda amanda >/dev/null 2>&1 || :
# in <= 11.1 use old disk group for amanda user
%else
    /usr/sbin/useradd -r -o -g disk -u 37 -s /bin/bash -c "Amanda admin" -d /var/lib/amanda amanda >/dev/null 2>&1 || :
%endif

%post
%run_permissions
%verifyscript
%verify_permissions -f /usr/lib/amanda/suidlist

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%doc amanda-howto-collection.pdf ChangeLog NEWS AUTHORS COPYRIGHT README ReleaseNotes
%doc %{_mandir}/man*/*
%config /usr/lib/amanda/exclude.gtar
%attr(755,root,root) %dir /usr/lib/amanda
%attr(664,amanda,%{amanda_group}) %config(noreplace) %{_sysconfdir}/dumpdates
%attr(664,amanda,%{amanda_group}) %config(noreplace) %{_sysconfdir}/amandates
%attr(755,amanda,%{amanda_group}) %dir %{_sysconfdir}/amanda
%attr(755,amanda,%{amanda_group}) %dir %{_sysconfdir}/amanda/example
%attr(755,amanda,%{amanda_group}) %dir /var/lib/amanda/
%attr(755,amanda,%{amanda_group}) %dir /var/lib/amanda/disklist
%attr(755,amanda,%{amanda_group}) %dir /var/lib/amanda/gnutar-lists/
%attr(755,amanda,%{amanda_group}) %dir /var/lib/amanda/index/
%attr(755,amanda,%{amanda_group}) %dir /var/lib/amanda/DailySet1
%attr(755,amanda,%{amanda_group}) %dir /var/lib/amanda/lbl-templ
%attr(644,amanda,%{amanda_group}) /var/lib/amanda/lbl-templ/*
%config %attr(644,amanda,%{amanda_group}) /var/lib/amanda/.bashrc
%config %attr(644,amanda,%{amanda_group}) /var/lib/amanda/.profile
# bnc#412636 file permissions of .amandahosts should be 600
%config %attr(600,amanda,%{amanda_group}) /var/lib/amanda/.amandahosts
%config %attr(644,amanda,%{amanda_group}) %{_sysconfdir}/amanda/example/amanda.conf
%config %attr(644,amanda,%{amanda_group}) %{_sysconfdir}/amanda/example/disklist
%config(noreplace) %{_sysconfdir}/xinetd.d/*
# perl scripts
%dir %{perl_vendorlib}/Amanda/
%dir %{perl_vendorlib}/Amanda/Application
%dir %{perl_vendorlib}/Amanda/Changer
%dir %{perl_vendorlib}/Amanda/DB
%dir %{perl_vendorlib}/auto/Amanda/
%dir %{perl_vendorlib}/auto/Amanda/Application
%dir %{perl_vendorlib}/auto/Amanda/Archive
%dir %{perl_vendorlib}/auto/Amanda/Cmdline
%dir %{perl_vendorlib}/auto/Amanda/Config
%dir %{perl_vendorlib}/auto/Amanda/Debug
%dir %{perl_vendorlib}/auto/Amanda/Device
%dir %{perl_vendorlib}/auto/Amanda/Logfile
%dir %{perl_vendorlib}/auto/Amanda/MainLoop
%dir %{perl_vendorlib}/auto/Amanda/Tapelist
%dir %{perl_vendorlib}/auto/Amanda/Tests
%dir %{perl_vendorlib}/auto/Amanda/Types
%dir %{perl_vendorlib}/auto/Amanda/Util
%dir %{perl_vendorlib}/auto/Amanda/Xfer
%{perl_vendorlib}/Amanda/*/*.pm
%{perl_vendorlib}/Amanda/*.pm
%{perl_vendorlib}/auto/Amanda/*/*.so
%defattr(755,amanda,%{amanda_group})
%{_sbindir}/amadmin
%{_sbindir}/amcheckdb
%{_sbindir}/amcleanup
%{_sbindir}/amdump
%{_sbindir}/amflush
%{_sbindir}/amgetconf
%{_sbindir}/amlabel
%{_sbindir}/amoverview
%{_sbindir}/amplot
%verify(not mode) %attr(0750,root,%{amanda_group}) %{_sbindir}/amcheck
%attr(0750,amanda,%{amanda_group}) %{_sbindir}/amrecover
%{_sbindir}/amreport
%{_sbindir}/amrestore
%{_sbindir}/amrmtape
%{_sbindir}/amstatus
%{_sbindir}/amtape
%{_sbindir}/amtapetype
%{_sbindir}/amtoc
%{_sbindir}/amcrypt-ossl
%{_sbindir}/amcrypt-ossl-asym
%{_sbindir}/amoldrecover
%{_sbindir}/amgpgcrypt
%{_sbindir}/amaespipe
%{_sbindir}/amcrypt
%{_sbindir}/amfetchdump
%{_sbindir}/amaddclient
%{_sbindir}/amarchiver
%{_sbindir}/amcheckdump
%{_sbindir}/amcryptsimple
%{_sbindir}/amdevcheck
%{_sbindir}/amserverconfig
%{_sbindir}/amservice
%{_sbindir}/amvault
%defattr(644,amanda,%{amanda_group})
/usr/lib/amanda/suidlist
/usr/lib/amanda/amcat.awk
/usr/lib/amanda/amplot.awk
/usr/lib/amanda/amplot.g
/usr/lib/amanda/amplot.gp
%defattr(755,amanda,%{amanda_group})
/usr/lib/amanda/amandad
/usr/lib/amanda/amidxtaped
/usr/lib/amanda/amindexd
/usr/lib/amanda/amtrmidx
/usr/lib/amanda/chg-mcutil
/usr/lib/amanda/chg-null
/usr/lib/amanda/chg-chio
/usr/lib/amanda/chg-chs
/usr/lib/amanda/chg-disk
/usr/lib/amanda/chg-iomega
/usr/lib/amanda/chg-juke
/usr/lib/amanda/chg-manual
/usr/lib/amanda/chg-mtx
/usr/lib/amanda/chg-multi
/usr/lib/amanda/chg-rait
/usr/lib/amanda/chg-rth
/usr/lib/amanda/chg-scsi
/usr/lib/amanda/chg-zd-mtx
/usr/lib/amanda/driver
/usr/lib/amanda/amcleanupdisk
/usr/lib/amanda/amlogroll
/usr/lib/amanda/amtrmlog
/usr/lib/amanda/patch-system
/usr/lib/amanda/selfcheck
/usr/lib/amanda/sendbackup
/usr/lib/amanda/sendsize
/usr/lib/amanda/taper
/usr/lib/amanda/versionsuffix
/usr/lib/amanda/chunker
/usr/lib/amanda/noop
/usr/lib/amanda/amanda-sh-lib.sh
/usr/lib/amanda/teecount
/usr/lib/amanda/chg-glue
/usr/lib/amanda/chg-lib.sh
%verify(not mode) %attr(0750,root,%{amanda_group})/usr/lib/amanda/calcsize
%verify(not mode) %attr(0750,root,%{amanda_group})/usr/lib/amanda/dumper
%verify(not mode) %attr(0750,root,%{amanda_group})/usr/lib/amanda/killpgrp
%verify(not mode) %attr(0750,root,%{amanda_group})/usr/lib/amanda/planner
%verify(not mode) %attr(0750,root,%{amanda_group})/usr/lib/amanda/rundump
%verify(not mode) %attr(0750,root,%{amanda_group})/usr/lib/amanda/runtar
%dir /usr/lib/amanda/application/
/usr/lib/amanda/application/*
# include shared libs
%dir %{_libdir}/amanda/
%{_libdir}/amanda/lib*
# excluding static libs
%exclude %{_libdir}/amanda/lib*.la
%exclude %{_libdir}/amanda/lib*.a
%exclude %{perl_vendorlib}/auto/Amanda/*/*.la
%exclude %{perl_vendorlib}/auto/Amanda/*/*.a

%changelog
* Mon Jun 11 2012 vdziewiecki@suse.com
-Fix bnc#739222 - Amanda is not running with the correct
  permissions behind xinetd
-Fix bnc#755268 - amanda backup system built without ssh
    support
* Wed Feb  9 2011 ro@suse.de
- amanda-2.6.1p1-newer_glib.patch:
  at least glib-2.27 brings g_list_free_full and g_slist_free_full
  with own definitions, prefix local variant with my_
* Mon Aug 30 2010 cristian.rodriguez@opensuse.org
- Do not hardcode build date in binaries
* Wed Nov 25 2009 meissner@suse.de
- rediffed patches
* Mon Aug 31 2009 ro@suse.de
- fix archive compression
* Wed Jul 29 2009 mseben@suse.cz
- updated to version 2.6.1p1
  - amplot: better output
  - don't include genversion.h in distribution tarballs.
  - many bugs fixed :S3 device driver,rait device driver
  amstatus, configure, application-api, others small bug
* Fri Jun 12 2009 mseben@suse.cz
- update to version 2.6.1
  - four new programs implementing application-api:
  amgtar, amstar, amsamba, amzfs-sendrecv
  - swithching from the program "GNUTAR" to the application "amgtar"
  - two new scripts implementing script-api : amzfs-snapshot, script-email
  - added new program amarchiver to manipulate file in amanda archive format
  - added new perl modules:
  * Application (perl utility functions for Applications)
  * Archive (Perl access to the  amanda archive library)
  * Constants (perl access to build-time configuration values)
  * MainLoop (Perl interface to the Glib MainLoop)
  * Process (interface to process), used by amcleanup.
  * Script (perl utility functions for Scripts)
  * Tapelist (Manipulate the Amanda tapelist)
  * Xfer (Xfer-api)
- obsolete *-no_chown.patch,*-chg-multi.patch,*-gnulib.patch
- added *-return_val.patch to fix NULL return value
- added *-amxfer_version.patch to fix libamxfer version name
- updated amanda-how-to-collection.pdf
- amanda user has now primary group amanda (created in %%pre phase)
  and supplementary group tape (see also bnc#523006)
* Mon Feb 16 2009 ro@suse.de
- drop lprng in buildreq
* Mon Aug 18 2008 lmichnovic@suse.cz
- fixed missing exclude.gtar file [bnc#412636]
- fixed .amandahosts permission [bnc#412636]
* Wed Jul 16 2008 lmichnovic@suse.cz
- removed unnecessary Requires on glibc-devel ncurses-devel
* Fri Jun 27 2008 schwab@suse.de
- Fix gnulib macros.
* Fri Apr 11 2008 schwab@suse.de
- Remove broken libtool macros.
* Fri Feb  1 2008 lmichnovic@suse.cz
- compiling with option --with-maxtapeblocksize=256 [bnc#353239]
* Fri Nov  9 2007 lmichnovic@suse.cz
- installing only *.txt documentation files
- no need for executable perms for file /usr/lib/amanda/suidlist
* Thu Jul 12 2007 lmichnovic@suse.cz
- added upstream chg-multi.patch
- fixed missing shellbang (shellbang.patch)
* Fri Jun  8 2007 lmichnovic@suse.cz
- update 2.5.2p1
  * Many IPv6 bugs fixed:
  + missing sockaddr_storage
  + missing AI_V4MAPPED and AI_ALL
  + compare of IPv4 and IPv6 v4mapped address.
  + (bsd/bsdudp): server use two sockets,
    one for IPv4 and one for IPv6
  * amflush/autoflush
  * chown/chmod
  * amstatus
  * compilation on some platform
* Thu May 17 2007 lmichnovic@suse.cz
- adjusted *no_chown.patch
* Thu May 17 2007 lmichnovic@suse.cz
- update to version 2.5.2 final
  * some more bug fixes against beta
* Tue Apr 24 2007 lmichnovic@suse.cz
- update to version 2.5.2 beta 1
  * Many bugs fixed and code cleanup
  * krb5 auth is working
  * Works with IPv6 address
  * Amanda configuration file changes
    o amanda.conf changes
    + debugging is enabled in the config file
    see all debug_* config option
    + tapetype 'readblocksize', if maxtapeblocksize is set too
    larger for your hardware
- installing HOWTO-collection.pdf as doc
- excluding static libs
* Tue Feb 13 2007 lmichnovic@suse.cz
- update to version 2.5.1p3
  * Many bugs fixed
  * amrecover improve handling of not ascii filename in index.
  * Works with tar-1.16 and exit status of 1.
  * Can define a LASTSLOT in a chg-disk config file.
  - obsoletes *overflow.patch
* Fri Feb  9 2007 ro@suse.de
- allow build as non-root
* Mon Jan 22 2007 lmichnovic@suse.cz
- added libxslt into BuildRequires
- fixed possible overflow (overflow.patch)
* Mon Jan 22 2007 lmichnovic@suse.cz
- updated to 2.5.1p2
  * Many bugs fixed
  * amoverview is working
  * dumptype starttime is working
  Amanda command changes
  - amtape accept the -o arguments
  - amgetconf --list to list all tapetype, dumptype, holdingdisk
    or interface
  - amgetconf can return a value of a specific tapetype, dumptype,
    holdingdisk or interface
* Thu Oct 19 2006 lmichnovic@suse.cz
- changed version to 2.5.1.1
- compiling with fPIC - fixes failing build on some archs
* Tue Oct  3 2006 pnemec@suse.cz
- updated to 2.5.1p1 which not contain license problem
  affected files #196765
  - many bugfixes see NEWS
- minor cleaning in specfile
* Mon Aug 28 2006 pnemec@suse.cz
- removed examples with license problems
  from source tarball #196765
* Fri Jul  7 2006 pnemec@suse.cz
- updated to 2.5.0p2
  added many new features in 2.5.0 (Auto tape labelling,
  security comunication ...)
  fixed many minors bug (in p1) and major bug (in p2)
- added pdf document with actualized howtos
* Thu Apr  6 2006 pnemec@suse.cz
- some other fix for bug #137128 SIGSEGV in amadmin
* Fri Feb 10 2006 pnemec@suse.cz
- aded *-srv.patch to fix bug #137128
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Aug  1 2005 mjancar@suse.cz
- update to 2.4.5
- add glibc-devel and ncurses-devel to Requires
* Mon Jun 20 2005 ro@suse.de
- added pie patch from FC
- use fPIC for libs needed when building binaries with fpie
* Thu Nov 18 2004 ro@suse.de
- use kerberos-devel-packages
* Tue Aug 10 2004 tcrhak@suse.cz
- update to 2.4.4p3
* Fri Feb 20 2004 tcrhak@suse.cz
- update to version 2.4.4p2
* Wed Oct 29 2003 ro@suse.de
- package according to permissions.secure and add run_permissions
* Thu Sep 18 2003 tcrhak@suse.cz
- added quotes around "grep -E" in an assignment in
  chg-manual; patch manual
- fixed script chg-zd-mtx: parse vars from config correctly,
  fixed output when mtx is not found
* Wed Jul 30 2003 stepan@suse.de
- change samba-client dependency to /usr/bin/smbclient
  to make it operable with samba tng
* Wed Jul 30 2003 aj@suse.de
- Fix chown arguments.
* Mon Jul 28 2003 tcrhak@suse.cz
- fixed script chg-zd-mtx
* Fri Jul 25 2003 tcrhak@suse.cz
- update to version 2.4.4p1
* Thu Jun 12 2003 kukuk@suse.de
- added directory to filelist
* Fri Jun  6 2003 mmj@suse.de
- Package forgotten files
- Remove files from buildroot installed elsewhere
* Mon Mar  3 2003 tcrhak@suse.cz
- added amanda libraries to filelist
* Fri Feb 28 2003 tcrhak@suse.cz
- update to version 2.4.4, that fixes many memory leaks
- added xinetd config files
* Fri Feb 14 2003 tcrhak@suse.cz
- update to version 2.4.3
- applied changes proposed for the tape changer script
  [bug #20086] - patch mtx
* Tue Oct 29 2002 ro@suse.de
- remove (old) libtool macros from acinclude.m4
* Fri Aug 30 2002 tcrhak@suse.cz
- fixed neededforbuild so that smbclient is identified by configure,
  added samba-client to Requires (bug #15818)
* Mon Jul  8 2002 mmj@suse.de
- Using useradd in the package itself.
* Wed Apr  3 2002 tcrhak@suse.cz
- build with new automake/autoconf
* Sat Mar  9 2002 ro@suse.de
- replaced lprold by lprng in neededforbuild
* Thu Nov 22 2001 tcrhak@suse.cz
- Added ps label templates (bugzilla #12270)
- Added README.SuSE
* Mon Nov 12 2001 schwab@suse.de
- Fix for automake 1.5 and autoconf 2.52.
* Mon Aug 20 2001 dan@suse.cz
- update to 2.4.2p2
* Fri May  4 2001 pblaha@suse.cz
- fix permisions 644 for .bashrc  .amandahosts and .profile
- in amanda home /var/lib/amanda/
* Thu Feb 22 2001 ro@suse.de
- added readline/readline-devel to neededforbuild (split from bash)
* Thu Jan 11 2001 sf@suse.de
- added './' and 'config' to %%{suse_update_config} to make
  it build on IA64
* Fri Jan  5 2001 smid@suse.cz
- file permission changes
- default configuration changes
* Sun Dec  3 2000 smid@suse.cz
- new version 2.4.2
* Tue Nov 21 2000 uli@suse.de
- fixed to build on PPC
* Mon Sep 25 2000 smid@suse.cz
- binaries moved to /usr/sbin
* Mon Sep 18 2000 smid@suse.cz
- Y2K bugfix
* Tue Jun 20 2000 schwab@suse.de
- Add %%suse_update_config.
* Thu May 25 2000 smid@suse.cz
- /usr/doc/packages => %%{_defaultdocdir}
* Fri Apr  7 2000 smid@suse.cz
- url added
* Thu Jan 20 2000 kukuk@suse.de
- /usr/man -> /usr/share/man
- clean up configuration and spec file
* Thu Oct  7 1999 kukuk@suse.de
- Add needed tools to needforbuild
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Jun 25 1999 kukuk@suse.de
- Update to 2.4.1p1 from jurix
- add glibc 2.1 patch
* Sat Dec  5 1998 ro@suse.de
- disabled setresuid/setresgid (while some are still using 2.0)
* Thu Feb  5 1998 florian@suse.de
- first rpm-package of amanda for SuSE
* Thu Jan  2 1997 florian@suse.de
- first S.u.S.E.-version of amanda 2.3.0
- not really supported yet...   :-)
